@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 #-*- coding: utf-8 -*-
 """
 pyScss, a Scss compiler for Python
@@ -43,9 +42,12 @@ xCSS:
     for both Py3.x and Py2.x
 
 """
+from __future__ import unicode_literals
 
-VERSION_INFO = (1, 2, 0, 'post1')
-DATE_INFO = (2013, 10, 8)  # YEAR, MONTH, DAY
+import sys
+
+VERSION_INFO = (1, 3, 0)
+DATE_INFO = (2014, 10, 15)  # YEAR, MONTH, DAY
 VERSION = '.'.join(str(i) for i in VERSION_INFO)
 REVISION = '%04d%02d%02d' % DATE_INFO
 BUILD_INFO = "pyScss v" + VERSION + " (" + REVISION + ")"
